// adapted from: http://www.codeproject.com/Articles/252566/Learning-Poco-GET-with-HTTP

#include <Poco/Net/HTTPClientSession.h>
#include <Poco/Net/HTTPRequest.h>
#include <Poco/Net/HTTPResponse.h>
#include <Poco/StreamCopier.h>
#include <Poco/Path.h>
#include <Poco/URI.h>
#include <Poco/Exception.h>
#include <iostream>
#include <string>

using namespace Poco::Net;
using namespace Poco;

int main(int argc, char** argv) {
    std::string uriStr;

    if (argc >= 2) {
        uriStr = argv[1];
    }
    else {
        uriStr = "http://www.codingnest.com/";
    }

    try {
        // prepare session
        URI uri(uriStr);
        HTTPClientSession session(uri.getHost(), uri.getPort());
        // prepare path
        std::string path = uri.getPathAndQuery();
        if (path.empty()) path = "/";

        // send request
        HTTPRequest req(HTTPRequest::HTTP_GET, path, HTTPMessage::HTTP_1_1);
        session.sendRequest(req);

        // get response
        HTTPResponse res;
        std::cout << res.getStatus() << " " << res.getReason() << "\n";

        // print response
        auto& is = session.receiveResponse(res);
        StreamCopier::copyStream(is, std::cout);

        // wait
        std::cin.get();
    }
    catch (Exception &ex) {
        std::cerr << ex.displayText() << "\n";
        
        // wait
        std::cin.get();
        return -1;
    }
}
